@@ -2,21 +2,24 @@ import requests
 
 from orijin_sdk.defaults import ENDPOINTS
 
-def login_full(email: str, password: str, endpoint = ENDPOINTS.brand_login):
+def login_full(email: str, password: str, custom_endpoint = ENDPOINTS.brand_login):
     """
     Request a login token to the Orijin system.
     Returns a json of the response, which if successful should include a user token at ["data"]["token"]
     """
-    r = requests.post(url=endpoint, json={"email":email, "password":password})
+    try:
+        r = requests.post(url=custom_endpoint, json={"email":email, "password":password})
+    except Exception as e:
+        print(e)
     return r.json()
 
-def login(email: str, password: str, endpoint) -> str | None:
+def login(email: str, password: str, custom_endpoint = ENDPOINTS.brand_login) -> str | None:
     """
     Request a login token to the Orijin system.
     Same as login_full(), but only the auth token is returned.
     """
     try:
-        return login_full(email, password, endpoint = ENDPOINTS.brand_login)["data"]["token"]
+        return login_full(email, password, custom_endpoint)["data"]["token"]
     except:
         return None
 
