@@ -10,9 +10,20 @@ class APIs:
         brand_login: str       = "/api/auth/login",
         brand_register: str    = "/api/auth/member/register",
     ) -> None:
-        self.gql                = domain + gql
-        self.file_uploads       = domain + file_uploads
-        self.consumer_login     = domain + consumer_login
-        self.consumer_register  = domain + consumer_register
-        self.brand_login        = domain + brand_login
-        self.brand_register     = domain + brand_register
\ No newline at end of file
+        self.gql                = domain.strip('/') + gql
+        self.file_uploads       = domain.strip('/') + file_uploads
+        self.consumer_login     = domain.strip('/') + consumer_login
+        self.consumer_register  = domain.strip('/') + consumer_register
+        self.brand_login        = domain.strip('/') + brand_login
+        self.brand_register     = domain.strip('/') + brand_register
+
+class User:
+    def __init__(
+        self,
+        email: str    = "",
+        password: str = "",
+        id            = None
+    ) -> None:
+        self.email    = email
+        self.password = password
+        self.id       = id
